@@ -17,11 +17,11 @@ Module::Starter::Simple - a simple, comprehensive Module::Starter plugin
 
 =head1 VERSION
 
-Version 1.59
+Version 1.61
 
 =cut
 
-our $VERSION = '1.59';
+our $VERSION = '1.61';
 
 =head1 SYNOPSIS
 
@@ -93,6 +93,14 @@ sub create_distro {
         croak "Invalid module name: $_" unless /\A[a-z_]\w*(?:::[\w]+)*\Z/i;
     }
 
+    if ( ( not $self->{author} ) && ( $^O ne 'MSWin32' ) ) {
+        ( $self->{author} ) = split /,/, ( getpwuid $> )[6];
+    }
+
+    if ( not $self->{email} and exists $ENV{EMAIL} ) {
+        $self->{email} = $ENV{EMAIL};
+    }
+
     croak "Must specify an author\n" unless $self->{author};
     croak "Must specify an email address\n" unless $self->{email};
     ($self->{email_obfuscated} = $self->{email}) =~ s/@/ at /;
